.. _api_constants:

=========
Constants
=========

Constants are used internally to ensure consistent use of keywords when parsing
and writing investigation, study and assay files (in particular in the
headers). They can also be used when creating a model from scratch, i.e. to
provide a desired header order (used for writing) when creating
study/assay nodes or investigation sections (or section entries).


.. contents::


Investigation Headers
---------------------

.. automodule:: altamisa.constants.investigation_headers
    :members:


Table Headers
-------------

.. automodule:: altamisa.constants.table_headers
    :members:


Table Restrictions
------------------

.. automodule:: altamisa.constants.table_restrictions
    :members:


Table Tokens
------------

.. automodule:: altamisa.constants.table_tokens
    :members:
